# GPTCMD

GPTCMD is a Python library for calling ChatGPT in the command line

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install GPTCMD.

```bash
pip install gptcmdfj
```

## Setup
Add your credentials ot .env.example in the site-package file, then delete the '.example' portion (so the file should be called .env)

## Usage

```bash
User> GPTCMD "can you hear me?"
As an artificial intelligence, I don't have the ability to hear. However, I can process and respond to the text inputs you provide.
```
